.. module:: numpy

.. _reference:

###############
NumPy Reference
###############

:Release: |version|
:Date: |today|

This reference manual details functions, modules, and objects
included in NumPy, describing what they are and what they do.
For learning how to use NumPy, see the :ref:`complete documentation <numpy_docs_mainpage>`.


.. toctree::
   :maxdepth: 2

   arrays
   array_api
   constants
   ufuncs
   routines
   typing
   global_state
   distutils
   distutils_guide
   distutils_status_migration
   c-api/index
   simd/index
   swig


Acknowledgements
================

Large parts of this manual originate from Travis E. Oliphant's book
`Guide to NumPy <https://archive.org/details/NumPyBook>`__ (which generously
entered Public Domain in August 2008). The reference documentation for many of
the functions are written by numerous contributors and developers of
NumPy.
